@@ -55,9 +55,6 @@ add_pending_items (gpointer data);
 static void
 spi_cache_finalize (GObject * object);
 
-static void
-spi_cache_dispose (GObject * object);
-
 /*---------------------------------------------------------------------------*/
 
 enum
@@ -79,7 +76,6 @@ static void spi_cache_class_init (SpiCacheClass * klass)
   spi_cache_parent_class = g_type_class_ref (G_TYPE_OBJECT);
 
   object_class->finalize = spi_cache_finalize;
-  object_class->dispose = spi_cache_dispose;
 
   cache_signals [OBJECT_ADDED] = \
       g_signal_new ("object-added",
@@ -154,14 +150,6 @@ spi_cache_finalize (GObject * object)
   G_OBJECT_CLASS (spi_cache_parent_class)->finalize (object);
 }
 
-static void
-spi_cache_dispose (GObject * object)
-{
-  SpiCache *cache = SPI_CACHE (object);
-
-  G_OBJECT_CLASS (spi_cache_parent_class)->dispose (object);
-}
-
 /*---------------------------------------------------------------------------*/
 
 static void
@@ -204,8 +192,9 @@ add_object (SpiCache * cache, GObject * gobj)
 /*---------------------------------------------------------------------------*/
 
 static GStaticRecMutex cache_mutex        = G_STATIC_REC_MUTEX_INIT;
-static GStaticMutex recursion_check_guard = G_STATIC_MUTEX_INIT;
 
+#ifdef SPI_ATK_DEBUG
+static GStaticMutex recursion_check_guard = G_STATIC_MUTEX_INIT;
 static gboolean recursion_check = FALSE;
 
 static gboolean
@@ -226,6 +215,7 @@ recursion_check_unset ()
   recursion_check = FALSE;
   g_static_mutex_unlock (&recursion_check_guard);
 }
+#endif /* SPI_ATK_DEBUG */
 
 /*---------------------------------------------------------------------------*/
 
